==> lima-swing-0.7.1-sources.jar: org/chorem/lima/ui/lettering/TypeEntry.java <==
package org.chorem.lima.ui.lettering;

/*
 * #%L
 * Lima :: Swing
 * $Id: TypeEntry.java 3740 2014-01-17 22:12:04Z dcosse $
 * $HeadURL: https://svn.chorem.org/lima/tags/lima-0.7.1/lima-swing/src/main/java/org/chorem/lima/ui/lettering/TypeEntry.java $
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import static org.nuiton.i18n.I18n._;

/**
 * @author Sylvain Bavencoff <bavencoff@codelutin.com>
 */
public enum  TypeEntry {

    LETTERED(true, false),

    NO_LETTERED(false, true),

    ALL(true, true);

    private boolean lettered;

    private boolean noLettered;

    private TypeEntry(boolean lettered, boolean noLettered) {
        this.lettered = lettered;
        this.noLettered = noLettered;
    }


    @Override
    public String toString() {

        String result = "";

        switch (this) {
            case LETTERED:
                result = _("lima.ui.lettering.checkLettredEntry");
                break;
            case NO_LETTERED:
                result = _("lima.ui.lettering.checkNoLettredEntry");
                break;
            case ALL:
                result = _("lima.ui.lettering.checkAll");
                break;
        }

        return  result;

    }

    public boolean isLettered() {
        return lettered;
    }

    public boolean isNoLettered() {
        return noLettered;
    }
}

==> lima-swing-0.7.2-sources.jar: org/chorem/lima/ui/lettering/TypeEntry.java <==
package org.chorem.lima.ui.lettering;

/*
 * #%L
 * Lima :: Swing
 * $Id: TypeEntry.java 3777 2014-04-14 07:29:08Z sbavencoff $
 * $HeadURL: https://svn.chorem.org/lima/tags/lima-0.7.2/lima-swing/src/main/java/org/chorem/lima/ui/lettering/TypeEntry.java $
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import static org.nuiton.i18n.I18n.t;

/**
 * @author Sylvain Bavencoff <bavencoff@codelutin.com>
 */
public enum  TypeEntry {

    LETTERED(true, false),

    NO_LETTERED(false, true),

    ALL(true, true);

    private boolean lettered;

    private boolean noLettered;

    private TypeEntry(boolean lettered, boolean noLettered) {
        this.lettered = lettered;
        this.noLettered = noLettered;
    }


    @Override
    public String toString() {

        String result = "";

        switch (this) {
            case LETTERED:
                result = t("lima.ui.lettering.checkLettredEntry");
                break;
            case NO_LETTERED:
                result = t("lima.ui.lettering.checkNoLettredEntry");
                break;
            case ALL:
                result = t("lima.ui.lettering.checkAll");
                break;
        }

        return  result;

    }

    public boolean isLettered() {
        return lettered;
    }

    public boolean isNoLettered() {
        return noLettered;
    }
}
